@@ -1,14 +1,11 @@
+from bdaserviceutils import task_args
+
 import importlib
-import sys
 
 
 def get_args():
 
-    args = {}
-    for _ in sys.argv[1:]:
-        if "=" in _:
-            p = _.split('=')
-            args[p[0].replace("--", "", 1)] = p[1]
+    args = task_args.get_args()
 
     if args["dataStorageType-input-dataset"].lower().startswith("presto"):
         args["input-columns"] = args["input-columns"] if "input-columns" in args else "*"
