@@ -4,7 +4,7 @@ from .datastorage import DataStorage
 class Hdfs(DataStorage):
 
     # overriding abstract method
-    def load_dataset(self, spark, read_all=True, input_dest='', header=True):
+    def load_dataset(self, read_all=True, input_dest='', header=True):
 
         if input_dest == '':
             input_dataset = self.args["input-dataset"]
@@ -15,7 +15,7 @@ class Hdfs(DataStorage):
         delimiter = self.args["delimiter"] if "delimiter" in self.args else ","
         input_file_format = self.args["inputFileFormat"] if "inputFileFormat" in self.args else "csv"
 
-        return spark.read.load("hdfs://"+hdfs_host+":"+hdfs_port+input_dataset, format=input_file_format, sep=delimiter, inferSchema=True, header=header, error_bad_lines=False)
+        return self.spark.read.load("hdfs://"+hdfs_host+":"+hdfs_port+input_dataset, format=input_file_format, sep=delimiter, inferSchema=True, header=header, error_bad_lines=False)
 
     # overriding abstract method
     def save_dataset(self, df, output_dest):
